<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Customer\Model\CustomerInterface;
use Sylius\Component\Resource\Model\ResourceInterface;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ORM\Entity()
 * @ORM\Table(name="dedi_blog_comment")
 */
class Comment implements CommentInterface, ResourceInterface
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\Column(name="id", type="integer", unique=true)
     */
    private ?int $id;

    /**
     * @ORM\Column(type="text", nullable=false, name="comment_content")
     * @Assert\NotBlank(groups={"default", "sylius"})
     */
    private string $content = '';

    /**
     * @ORM\ManyToOne(targetEntity="\Sylius\Component\Customer\Model\CustomerInterface")
     * @ORM\JoinColumn(name="customer_id", referencedColumnName="id", nullable=false)
     */
    private ?CustomerInterface $customer;

    /**
     * @ORM\ManyToOne(targetEntity="Dedi\SyliusBlogPlugin\Entity\ArticleInterface", inversedBy="comments")
     * @ORM\JoinColumn(name="article_id", referencedColumnName="id", nullable=false)
     */
    private ?ArticleInterface $article;

    /**
     * @ORM\Column(type="datetime", nullable=false, name="comment_created_at")
     */
    private \DateTime $createdAt;

    /** @ORM\Column(type="string") */
    protected $status = CommentInterface::STATUS_NEW;

    public function __construct()
    {
        $this->createdAt = new \DateTime();
    }

    public function getContent(): string
    {
        return (string) $this->content;
    }

    public function setContent(string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getArticle(): ArticleInterface
    {
        return $this->article;
    }

    public function setArticle(ArticleInterface $article): self
    {
        $this->article = $article;

        return $this;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * {@inheritdoc}
     */
    public function getCustomer(): ?CustomerInterface
    {
        return $this->customer;
    }

    /**
     * {@inheritdoc}
     */
    public function setCustomer(?CustomerInterface $customer): self
    {
        $this->customer = $customer;

        return $this;
    }

    public function setCreatedAt(\DateTime $createdAt)
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function getCreatedAt(): \DateTime
    {
        return $this->createdAt;
    }

    public function setStatus(string $status): void
    {
        $this->status = $status;
    }

    public function getStatus(): string
    {
        return $this->status;
    }
}
